package com.xxh.cloud.frontend.common.modules.his;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.core.util.URLUtil;
import cn.hutool.crypto.SmUtil;
import cn.hutool.http.HttpRequest;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.xxh.cloud.frontend.common.modules.his.config.HisWebConfig;
import com.xxh.cloud.frontend.common.modules.his.dto.HisGenerateSchemeDTO;
import com.xxh.cloud.frontend.common.modules.his.dto.HisPatientDTO;
import com.xxh.cloud.frontend.common.modules.his.dto.HisPromotionCodeDTO;
import com.xxh.cloud.frontend.common.modules.his.model.HisBaseModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisDeptListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisDoctorListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisPatientListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisPromotionCodeModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisSchemeUrlModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisWxTokenModel;
import com.xxh.cloud.frontend.common.modules.his.model.PatBindModel;
import com.xxh.cloud.frontend.common.modules.his.model.PatInfoModel;

import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Component;

/**
 * 互联网医院
 */
@Slf4j
@Component
public class HisWebApiHelper {

    // host
    // 内网：https://172.18.84.91:10053
    // 外网：https://hlwyy.bydsfy.com:10053
    // private static final String host = "https://hlwyy.bydsfy.com:10053";

    // 获取微信accesstoken
    private static String accessToken = "/patient/vd3/getWxToken";

    // 获取就诊人信息
    private static String patientByUnionIdUrl = "/patient/v1/other/getPatientByUnionId";

    // 批量获取就诊人信息
    private static String getPatientByTimestamp = "/patient/vd3/getPatientByTimestamp";

    // 获取科室信息
    private static String deptsInfoUrl = "/patient/vd3/getDeptsInfo";

    // 获取医生信息 
    private static String doctorsInfoUrl = "/patient/vd3/getDoctorsInfo";

    // 获取schemaUrl信息
    private static String wxMiniSchemeUrl = "/patient/vd3/getWxMiniSchemeUrl";

    // 获取schemaUrl跳转路径参数
    private static String jumpPath = "pages/tab_bar/hospHome/hospHome";

    // 获取推荐码信息
    private static String getPromotionCodeUrl = "/patient/vd3/getPromotionCodeInfo";

    // 保存推荐码信息
    private static String savePromotionCodeUrl = "/patient/vd3/savePromotionCode";

    // 获取accessToken信息
    public static HisWxTokenModel getAccessToken(HisWebConfig config, String type) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("type", type);

        String body = JSON.toJSONString(reqMap);
        log.info("获取微信accessToken参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + accessToken, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }
        
        HisBaseModel<HisWxTokenModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisWxTokenModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 获取就诊人信息
    public static PatBindModel getPatientByUnionId(HisWebConfig config, String unionid) {
        PatBindModel patBindModel = new PatBindModel();

        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("unionid", unionid);

        String body = JSON.toJSONString(reqMap);
        log.info("获取就诊人信息参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + patientByUnionIdUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return patBindModel;
        }

        System.out.println(result);

        HisBaseModel<HisPatientListModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisPatientListModel>>(){});
        if (null == resultModel) {
            return patBindModel;
        }

        patBindModel.setCode(resultModel.getStatus());
        patBindModel.setMsg(resultModel.getMsg());

        List<PatInfoModel> patInfoList = new ArrayList<>();
        if (null != resultModel.getData() && CollUtil.isNotEmpty(resultModel.getData().getPatients())) {
            resultModel.getData().getPatients().forEach(i -> {
                PatInfoModel patInfo = new PatInfoModel();
                patInfo.setBirthday(i.getBirthday());
                patInfo.setPatientId(i.getHisPatientId());
                patInfo.setPatHisNo(i.getHisPatientId());
                patInfo.setPatientName(i.getName());
                patInfo.setPatientMobile(i.getLinkPhone());
                patInfo.setIdNo(i.getPaperNo());
                patInfo.setIdType("1"); // 1:二代身份证 2:港澳居民身份证 3:台湾居民身份证 4:护照
                patInfo.setPatientSex("女".equals(i.getSex()) ? "F" : "M");

                patInfo.setIsDefault(i.getIsDefault());
                patInfo.setRelationName(i.getLinkRelationName());

                patInfo.setOpenId(i.getOpenId());
                patInfo.setUnionid(i.getUnionid());

                patInfo.setCreateDate(i.getCreateDate());
                patInfo.setUpdateDate(i.getUpdateDate());

                patInfo.setEnable(i.getEnable());

                patInfoList.add(patInfo);
            });
        }
        patBindModel.setData(patInfoList);


        return patBindModel;
    }

    // 获取就诊人信息
    public static PatBindModel getPatientByThirdId(HisWebConfig config, HisPatientDTO params) {
        PatBindModel patBindModel = new PatBindModel();

        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("hospitalId", "80158");
        if (StrUtil.isNotBlank(params.getOpenid())) {
            reqMap.put("openid", params.getOpenid());
        }
        if (StrUtil.isNotBlank(params.getUnionid())) {
            reqMap.put("unionid", params.getUnionid());
        }

        String body = JSON.toJSONString(reqMap);
        log.info("获取就诊人信息参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + patientByUnionIdUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return patBindModel;
        }

        System.out.println(result);

        HisBaseModel<HisPatientListModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisPatientListModel>>(){});
        if (null == resultModel) {
            return patBindModel;
        }

        patBindModel.setCode(resultModel.getStatus());
        patBindModel.setMsg(resultModel.getMsg());

        List<PatInfoModel> patInfoList = new ArrayList<>();
        if (null != resultModel.getData() && CollUtil.isNotEmpty(resultModel.getData().getPatients())) {
            resultModel.getData().getPatients().forEach(i -> {
                PatInfoModel patInfo = new PatInfoModel();
                patInfo.setBirthday(i.getBirthday());
                patInfo.setPatientId(i.getHisPatientId());
                patInfo.setPatHisNo(i.getHisPatientId());
                patInfo.setPatientName(i.getName());
                patInfo.setPatientMobile(i.getLinkPhone());
                patInfo.setIdNo(i.getPaperNo());
                patInfo.setIdType("1"); // 1:二代身份证 2:港澳居民身份证 3:台湾居民身份证 4:护照
                patInfo.setPatientSex("女".equals(i.getSex()) ? "F" : "M");

                patInfo.setIsDefault(i.getIsDefault());
                patInfo.setRelationName(i.getLinkRelationName());
                if (StrUtil.isBlank(i.getLinkRelationName()) && StrUtil.isNotBlank(i.getRelation())) {
                    patInfo.setRelationName(i.getRelation());
                }
                patInfo.setRelationType(relationType(i.getRelationId()));

                patInfo.setOpenId(i.getOpenId());
                patInfo.setUnionid(i.getUnionid());

                patInfo.setCreateDate(i.getCreateDate());
                patInfo.setUpdateDate(i.getUpdateDate());

                patInfo.setEnable(i.getEnable());

                patInfoList.add(patInfo);
            });
        }
        patBindModel.setData(patInfoList);


        return patBindModel;
    }

    // 原关系：0-本人，1-父母，2-子女，3-夫妻，4-亲属，5-朋友，6-其他
    // 整理后的关系：1:本人 2:配偶 3:父母 4:子女 5:他人
    private static String relationType(String relationId) {
        if (StrUtil.isBlank(relationId)) {
            return null;
        }

        if ("0".equals(relationId)) {
            return "1";
        } else if ("1".equals(relationId)) {
            return "3";
        } else if ("2".equals(relationId)) {
            return "4";
        } else if ("3".equals(relationId)) {
            return "2";
        } else {
            return "5";
        }
    }

    // 时间戳获取就诊人信息
    public static HisPatientListModel getPatientByTimestamp(HisWebConfig config, HisPatientDTO params) {
        Map<String, Object> reqMap = new HashMap<>();
        reqMap.put("startTime", DateUtil.format(DateUtil.parseDateTime(params.getStartTime()), "yyyyMMddHHmmss"));
        reqMap.put("endTime", DateUtil.format(DateUtil.parseDateTime(params.getEndTime()), "yyyyMMddHHmmss"));
        reqMap.put("pageNoReq", params.getPage());
        reqMap.put("pageSizeReq", params.getRows());

        String body = JSON.toJSONString(reqMap);
        log.info("获取就诊人信息参数 >>>>>>：{}", body);

        System.out.println("参数：" + body);

        String result = loopPostHttp(config.getHost() + getPatientByTimestamp, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }

        HisBaseModel<HisPatientListModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisPatientListModel>>(){});
        if (null == resultModel) {
            return null;
        }

        log.info("获取就诊人信息 <<<< {}", resultModel.getData().getPatients().size());
        return resultModel.getData();
    }

    // 获取科室信息
    public static HisDeptListModel getDeptsInfo(HisWebConfig config) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("hospitalId", "80158");

        String body = JSON.toJSONString(reqMap);
        log.info("获取科室信息参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + deptsInfoUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }
        
        HisBaseModel<HisDeptListModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisDeptListModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 获取医生信息 
    // 1：获取全部医生
    public static HisDoctorListModel getDoctorsInfo(HisWebConfig config, String showModel) {
        Map<String, String> reqMap = new HashMap<>();
        if (StrUtil.isBlank(showModel)) {
            showModel = "1";
        }
        reqMap.put("showModel", showModel);

        String body = JSON.toJSONString(reqMap);
        log.info("获取医生信息参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + doctorsInfoUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }
        
        HisBaseModel<HisDoctorListModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisDoctorListModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 获取schemeurl
    public static HisSchemeUrlModel getWxMiniSchemeUrl(HisWebConfig config, HisGenerateSchemeDTO params) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("hospId", "80158");
        if ("1".equals(params.getType())) { // 医生
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", "actionType=76&drId=" + params.getDoctorId());
        } else if ("2".equals(params.getType())) { // 科室排班
            String queryParam = URLUtil.encode("actionType=75&deptId=" + params.getDeptId() + "&deptName=" + params.getDeptName() + "&hisDeptId=" + params.getHisDeptId() + "&regType=2&scheduleMode=0");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        } else if ("3".equals(params.getType())) { // 门诊缴费
            String queryParam = URLUtil.encode("actionType=03");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        } else if ("4".equals(params.getType())) { // 排队候诊
            String queryParam = URLUtil.encode("actionType=11");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        }else if ("5".equals(params.getType())) { // 自助入院
            String queryParam = URLUtil.encode("actionType=41");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        }else if ("6".equals(params.getType())) { // 在线复诊
            String queryParam = URLUtil.encode("actionType=15");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        }else if ("7".equals(params.getType())) { // 报告查询
            String queryParam = URLUtil.encode("actionType=05");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        }else if ("8".equals(params.getType())) { // 药品清单
            String queryParam = URLUtil.encode("actionType=35");
            reqMap.put("jumpPath", jumpPath);
            reqMap.put("queryParam", queryParam);
        }

        String body = JSON.toJSONString(reqMap);
        log.info("获取schemeurl参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + wxMiniSchemeUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }

        log.info("获取schemeurl <<<< {}", result);
        
        HisBaseModel<HisSchemeUrlModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisSchemeUrlModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 获取推荐码信息 
    public static HisPromotionCodeModel getPromotionCodeUrl(HisWebConfig config, HisPromotionCodeDTO params) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("promotionCode", params.getPromotionCode());
        reqMap.put("promotionCodeType", params.getPromotionCodeType());

        String body = JSON.toJSONString(reqMap);
        log.info("获取推荐码参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + getPromotionCodeUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }

        log.info("获取推荐码结果 <<<< {}", result);
        
        HisBaseModel<HisPromotionCodeModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisPromotionCodeModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 保存推荐码信息 
    public static HisPromotionCodeModel savePromotionCodeUrl(HisWebConfig config, String promotionId) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("promotionCode", promotionId);

        String body = JSON.toJSONString(reqMap);
        log.info("保存推荐码信息参数 >>>>>>：{}", body);

        String result = loopPostHttp(config.getHost() + savePromotionCodeUrl, getSign(config.getSignKey(), body), body, 0);
        if (StrUtil.isBlank(result)) {
            return null;
        }

        log.info("保存推荐码结果 <<<< {}", result);
        
        HisBaseModel<HisPromotionCodeModel> resultModel = JSONObject.parseObject(result, new TypeReference<HisBaseModel<HisPromotionCodeModel>>(){});
        if (null == resultModel) {
            return null;
        }

        return resultModel.getData();
    }

    // 调用失败则暂停5秒重新请求，最多重调5次
    private static String loopPostHttp(String url, Map<String, String> headers, String body, Integer loopNum) {
        try {
            String result = HttpRequest.post(url)
                .addHeaders(headers)
                .body(body)
                .execute().body();
    
            return result;
        } catch (Exception e) {
            log.info("POST调用异常: {} ", url);
            e.printStackTrace();
            
            // 最多循环5次
            if (loopNum < 5) {
                // 先暂停
                log.info("休眠5000ms");
                try {
                    Thread.sleep(5000);
                } catch (InterruptedException e1) {
                    e1.printStackTrace();
                }
                // 出现异常再次调用
                return loopPostHttp(url, headers, body, loopNum + 1);
            }
        }

        return null;
    }

    private static Map<String, String> getSign(String signKey, String body) {

        String nonce = IdUtil.simpleUUID();
        Long timestamp = System.currentTimeMillis();
        String salt = nonce.substring(5);
        // String signKey = "KejYvc77zdzf7epuMs2UB2RdeP5QU5V6bqwvDdY2HBKtdZXD9Bv5F7FMHBPmJFK7";

        String sm3Body = SmUtil.sm3(body).toLowerCase();
        String sign = SmUtil.sm3(signKey + nonce + salt + sm3Body).toLowerCase();

        Map<String, String> headerMap = new HashMap<>();
        headerMap.put("nonce", nonce);
        headerMap.put("timestamp", String.valueOf(timestamp));
        headerMap.put("hospitalId", "80158");
        headerMap.put("signature", sign);
        headerMap.put("appType", "40");

        log.info("header 信息：{}", JSON.toJSONString(headerMap));

        return headerMap;
    }
    
    public static void main(String[] args) {
        HisWebConfig config = new HisWebConfig();
        config.setHost("https://hlwyy.bydsfy.com:10053");
        // config.setHost("https://172.18.84.91:10053");
        config.setSignKey("KejYvc77zdzf7epuMs2UB2RdeP5QU5V6bqwvDdY2HBKtdZXD9Bv5F7FMHBPmJFK7");

        // HisWxTokenModel token = getAccessToken(config, "2");
        // System.out.println(JSON.toJSONString(token));


        // 获取关联就诊卡号>>>> config={"host":"http://172.18.84.102:8081/api/frontend"}; params=o4qwy6hYRvfAx-O4QOgMZHh9H10Q

        // 王建军：o6jK353r1vzxKANJJizc8oQ65vfk      o4qwy6n2YVdeo_A5raTS1Maj1ps4

        // 马文洁：o6jK357Cm6dmVuIk8R9rRz604yiQ      o4qwy6tlgBr1xbCzU91uOlNSIulQ

        // 董瑞兴：o6jK358hHVyrt7rooS6XcQgAw01k      o4qwy6h5M4TDjgTPP1DL2f-aoWi8

        // 赵宇晴：o6jK35xJtO_XaCtvBrXy2WiMCmnU

        // 王宏宇：o6jK358cVF3c-lzV4Ft4e1ExusBw      o4qwy6ovCnm3x1nJBTgE0D0oSloQ

        // 李明：o6jK352u-eNoiEeQb2KsUKwAF8_c        o4qwy6u8VC18xb0Za47Dic1zzEb8

        // zs   o4qwy6txe8UH5LejGC8Tn9q7PWA4
        // 通过unionid获取家属信息
        // PatBindModel patientList = getPatientByUnionId(config, "o4qwy6nkRC1Jc0U_5PLVs93CfxAE");
        // System.out.println(JSON.toJSONString(patientList));


        /** 2024-08-12拉取的最近60条数据(2024-08-12 00:01:24   -   2024-08-12 11:01:54) 
         * 1 表示有信息但没患者名称编号等
         *  0 表示没有患者信息
         */

        // 通过openid或unionid获取家属信息  o6jK350Wg0oQHyI_Ia44J5dErkCk  o4qwy6spmV29f87lqzBiNyfL-NZo
        // System.out.println(System.currentTimeMillis());
        HisPatientDTO hisPatientDTO = new HisPatientDTO();
        // // hisPatientDTO.setOpenid("o6jK358kbesGCZRqlGrsjPLh6Hdg");
        // // hisPatientDTO.setOpenid("o6jK356aXluC_uTj7AtP4Z4sThQ4");
        // // hisPatientDTO.setUnionid("o4qwy6jMmJNu64HQux60evyq9Brc");
        // // hisPatientDTO.setOpenid("o6jK350Wg0oQHyI_Ia44J5dErkCk");
        // // hisPatientDTO.setUnionid("o4qwy6spmV29f87lqzBiNyfL-NZo");
        hisPatientDTO.setOpenid("o6jK358hHVyrt7rooS6XcQgAw01k");
        // hisPatientDTO.setUnionid("o4qwy6txe8UH5LejGC8Tn9q7PWA4");
        getPatientByThirdId(config, hisPatientDTO);
        // System.out.println(System.currentTimeMillis());

        // o6jK35zCgXVyIgb00owR-8WQ_T-U     o4qwy6nkRC1Jc0U_5PLVs93CfxAE
        // 批量获取患者信息
        // HisPatientDTO hisPatientDTO = new HisPatientDTO();
        // hisPatientDTO.setPage(1);
        // hisPatientDTO.setRows(500);
        // hisPatientDTO.setStartTime("2024-10-25 17:20:00");
        // hisPatientDTO.setEndTime("2024-10-25 17:30:00");
        // HisPatientListModel patientListByTimestamp = getPatientByTimestamp(config, hisPatientDTO);
        // System.out.println(JSON.toJSONString(patientListByTimestamp));

        // HisDeptListModel deptList = getDeptsInfo(config);
        // System.out.println(JSON.toJSONString(deptList));


        // HisDoctorListModel doctorList = getDoctorsInfo(config, "1");
        // System.out.println(JSON.toJSONString(doctorList));


        // // 医生主页
        // HisGenerateSchemeDTO doctorParams = new HisGenerateSchemeDTO();
        // doctorParams.setType("1");
        // doctorParams.setDoctorId("1111201667");
        // HisSchemeUrlModel doctor = getWxMiniSchemeUrl(config, doctorParams);
        // System.out.println(JSON.toJSONString(doctor));

        // 挂号排版
        // HisGenerateSchemeDTO doctorParams = new HisGenerateSchemeDTO();
        // doctorParams.setType("2");
        // doctorParams.setDeptId("1111137800");
        // doctorParams.setDeptName("生殖医学科门诊");
        // doctorParams.setHisDeptId("3451");
        // HisSchemeUrlModel register = getWxMiniSchemeUrl(config, doctorParams);
        // System.out.println(JSON.toJSONString(register));

        // SchemeUrl
        // HisGenerateSchemeDTO params3 = new HisGenerateSchemeDTO();
        // params3.setType("3");
        // System.out.println("门诊缴费------: " + getWxMiniSchemeUrl(config, params3).getSchemeUrl());
        
        // HisGenerateSchemeDTO params4 = new HisGenerateSchemeDTO();
        // params4.setType("4");
        // System.out.println("排队候诊------: " + getWxMiniSchemeUrl(config, params4).getSchemeUrl());
        
        // HisGenerateSchemeDTO params5 = new HisGenerateSchemeDTO();
        // params5.setType("5");
        // System.out.println("自助入院------: " + getWxMiniSchemeUrl(config, params5).getSchemeUrl());
        
        // HisGenerateSchemeDTO params6 = new HisGenerateSchemeDTO();
        // params6.setType("6");
        // System.out.println("在线复诊------: " + getWxMiniSchemeUrl(config, params6).getSchemeUrl());
        
        // HisGenerateSchemeDTO params7 = new HisGenerateSchemeDTO();
        // params7.setType("7");
        // System.out.println("报告查询------: " + getWxMiniSchemeUrl(config, params7).getSchemeUrl());
        
        // HisGenerateSchemeDTO params8 = new HisGenerateSchemeDTO();
        // params8.setType("8");
        // System.out.println("药品清单------: " + getWxMiniSchemeUrl(config, params8).getSchemeUrl());



        // 推荐码
        // HisPromotionCodeDTO hisPromotionCodeDTO = new HisPromotionCodeDTO();
        // hisPromotionCodeDTO.setPromotionCode("000166");
        // hisPromotionCodeDTO.setPromotionCodeType("1");
        // HisPromotionCodeModel promotionCode = getPromotionCodeUrl(config, hisPromotionCodeDTO);

        // System.out.println();

        // if (null != promotionCode && StrUtil.isNotBlank(promotionCode.getPromotionCode()) && StrUtil.isNotBlank(promotionCode.getPromotionCodeId())) {
        //     savePromotionCodeUrl(config, promotionCode.getPromotionCodeId());
        // }

        // savePromotionCodeUrl(config, "30001");
    }

}
