package com.xxh.cloud.frontend.common.modules.weixin;

import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.config.WxApiConfig;
import com.company.cloud.sdk.weixin.mp.WxMpApi;
import com.company.cloud.sdk.weixin.mp.model.AccessTokenModel;
import com.company.cloud.sdk.weixin.mp.model.AccessTokenResp;
import com.company.cloud.sdk.weixin.mp.model.JsapiTicketModel;
import com.company.cloud.sdk.weixin.mp.model.JsapiTicketResp;
import com.xxh.cloud.frontend.common.modules.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.frontend.common.modules.exception.BusinessException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

/**
 * 微信公众号和小程序 :全局唯一接口调用凭据 AccessToken
 * 公众号: 全局 jsapi_ticket的有效期为7200秒
 * */
@Slf4j
@Service
@CacheConfig(cacheNames = "{CATEGORY}")
public class ThirdWeixinAccessTokenService {

    @Cacheable(key = "#config.appid")
    public String getAccessToken(WxApiConfig config){
        log.info("---getAccessToken(WxApiConfig config):" + JSONObject.toJSONString(config));
        AccessTokenResp accessTokenResp=this._getAccessToken(config);
        if(accessTokenResp==null){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR);
        }
        log.info(JSONObject.toJSONString(accessTokenResp));
        String accessToken = accessTokenResp.getAccess_token();
        return accessToken;
    }

    public JsapiTicketResp getJsapiToken(String accessToken){
        log.info("---getJsapiToken(String accessToken)" + accessToken);
        JsapiTicketResp jsapiTicketResp=this._getJsapiToken(accessToken);
        if(jsapiTicketResp==null){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR);
        }
        log.info(JSONObject.toJSONString(jsapiTicketResp));
        return jsapiTicketResp;
    }

    private AccessTokenResp _getAccessToken(WxApiConfig config){
        AccessTokenModel param=new AccessTokenModel();
        param.setAppid(config.getAppid());
        param.setSecret(config.getSecret());
        AccessTokenResp resp= WxMpApi.accessToken(param);
        return resp;
    }

    private JsapiTicketResp _getJsapiToken(String accessToken){
        JsapiTicketModel wxReq=new JsapiTicketModel();
        wxReq.setAccess_token(accessToken);
        JsapiTicketResp resp= WxMpApi.jsapiTicket(wxReq);
        return resp;
    }

}
