package com.xxh.cloud.frontend.common.modules.weixin;

import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.StrUtil;

import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.config.WxApiConfig;
import com.company.cloud.sdk.weixin.mp.WxMpMsgManageApi;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.SendTempMsgDataModel;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.SendTempMsgModel;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.SendTempMsgResp;
import com.xxh.cloud.frontend.common.modules.exception.BusinessException;
import com.xxh.cloud.frontend.common.modules.exception.WechatBaseErrorEnum;
import com.xxh.cloud.frontend.common.modules.his.HisApiHelper;
import com.xxh.cloud.frontend.common.modules.his.config.SysProjectConfig;
import com.xxh.cloud.frontend.common.modules.his.model.HisAccessTokenModel;
import com.xxh.cloud.frontend.common.modules.modules.Result;
import com.xxh.cloud.frontend.common.modules.weixin.dto.SendTempMsgDTO;

import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 *  微信公众号，提送消息
 * */
@Log4j2
@Service
public class ThirdWeixinSendTempMsgService {

    @Autowired
    private SysProjectConfig sysProjectConfig;
    @Autowired
    private ThirdWeixinAccessTokenService thirdWeixinAccessTokenService;

    public SendTempMsgResp sendTempMsg(SendTempMsgDTO params){
        if (StrUtil.isBlank(params.getAccessToken())) {
            // TODO mj-li 临时方案，从新获取token
            if ("his".equals(sysProjectConfig.getAccess())) { //调用his获取
                Result<HisAccessTokenModel> resp = HisApiHelper.getAccessToken(sysProjectConfig);
                if (resp.getCode() != 0) {
                    log.error("----获取AccessToken失败----");
                }
                params.setAccessToken(resp.getData().getAccToken());
            } else { //调用微信获取
                WxApiConfig wxApiConfig = new WxApiConfig();
                wxApiConfig.setAppid(sysProjectConfig.getAppid());
                wxApiConfig.setSecret(sysProjectConfig.getSecret());
                String accessToken = thirdWeixinAccessTokenService.getAccessToken(wxApiConfig);
                params.setAccessToken(accessToken);
            }
        }
        // 发送规则的校验
        tempMsgCheck(params);
        // 发送
        SendTempMsgModel model = new SendTempMsgModel();
        model.setTouser(params.getOpenid());
        model.setTemplate_id(params.getTemplateId());
        model.setUrl(params.getUrl());

        if (MapUtil.isNotEmpty(params.getTempData())) {
            Map<String, SendTempMsgDataModel> data = new HashMap<>();
            Map<String, String> map = params.getTempData();
            map.forEach((k, v) -> {
                SendTempMsgDataModel sendTempMsgDataModel = new SendTempMsgDataModel(v);
                data.put(k, sendTempMsgDataModel);
            });
            model.setData(data);
        }

        log.info("wechat mp request send template message >>> : {}", JSONObject.toJSONString(model));
        SendTempMsgResp resp = WxMpMsgManageApi.sendTempMsg(params.getAccessToken(), model);
        log.info("wechat mp response send template message <<< : {}", JSONObject.toJSONString(resp));
        return resp;
    }

    private void tempMsgCheck(SendTempMsgDTO params) {
        if (sysProjectConfig.isCheckEnable()) {
            if (!sysProjectConfig.whiteList().contains(params.getOpenid())) {
                log.info("白名单校验-白名单中不存在openid:{}", params.getOpenid());
                throw new BusinessException(WechatBaseErrorEnum.TEMP_MSG_WHITE_NONE);
            }
        }
    }
}
