package com.xxh.cloud.frontend.custuser.web.controller;


import com.company.cloud.sdk.weixin.common.config.WxApiConfig;
import com.xxh.cloud.frontend.common.modules.his.HisApiHelper;
import com.xxh.cloud.frontend.common.modules.his.config.SysProjectConfig;
import com.xxh.cloud.frontend.common.modules.his.dto.GenerateSchemeDTO;
import com.xxh.cloud.frontend.common.modules.his.model.GenerateSchemeModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisAccessTokenModel;
import com.xxh.cloud.frontend.common.modules.his.model.PatBindModel;
import com.xxh.cloud.frontend.common.modules.modules.Result;
import com.xxh.cloud.frontend.common.modules.util.IpWhite;
import com.xxh.cloud.frontend.common.modules.weixin.ThirdWeixinAccessTokenService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/api/customize")
@Api(tags="调用第三方客户服务接口")
public class CustomerApiController {

    @Autowired
    private SysProjectConfig config;
    @Autowired
    private ThirdWeixinAccessTokenService thirdWeixinAccessTokenService;
    @Autowired
    private IpWhite ipWhite;

    @GetMapping("/getAccessToken")
    @ApiOperation("获取accessToken")
    public Result<HisAccessTokenModel> getAccessToken() {
        // ip白名单限制
        ipWhite.validatorIpWhite();
        
        if ("his".equals(config.getAccess())) { //调用his获取
            Result<HisAccessTokenModel> resp = HisApiHelper.getAccessToken(config);
            if (resp.getCode() != 0) {
                log.error("----获取AccessToken失败----");
            }
            return resp;
        } else { //调用微信获取
            WxApiConfig wxApiConfig = new WxApiConfig();
            wxApiConfig.setAppid(config.getAppid());
            wxApiConfig.setSecret(config.getSecret());
            String accessToken = thirdWeixinAccessTokenService.getAccessToken(wxApiConfig);
            HisAccessTokenModel model = new HisAccessTokenModel();
            model.setAccToken(accessToken);
            return new Result<HisAccessTokenModel>().ok(model);
        }
    }

    @GetMapping("/getPatInfoByOpenId")
    @ApiOperation("获取关联就诊卡号列表")
    public Result<PatBindModel> getPatInfoByOpenId(@RequestParam("userId") String userId) {
        // ip白名单限制
        ipWhite.validatorIpWhite();
        
        PatBindModel resp = HisApiHelper.getPatBind(config, userId);
        if (resp.getCode() != 0) {
            log.error("----获取关联就诊卡号列表----");
        }
        return new Result<PatBindModel>().ok(resp);
    }

    @PostMapping("/generatescheme")
    @ApiOperation("获取schemeurl")
    public Result<GenerateSchemeModel> getPatInfoByOpenId(@RequestBody GenerateSchemeDTO params) {
        // ip白名单限制
        ipWhite.validatorIpWhite();
        
        Result<GenerateSchemeModel> resp = HisApiHelper.generateScheme(config, params);
        if (resp.getCode() != 0) {
            log.error("----获取schemeurl----");
        }
        return resp;
    }
}
