package com.xxh.cloud.frontend.custuser.web.controller;

import com.xxh.cloud.frontend.common.modules.his.HisWebApiHelper;
import com.xxh.cloud.frontend.common.modules.his.config.HisWebConfig;
import com.xxh.cloud.frontend.common.modules.his.dto.HisGenerateSchemeDTO;
import com.xxh.cloud.frontend.common.modules.his.dto.HisPatientDTO;
import com.xxh.cloud.frontend.common.modules.his.dto.HisPromotionCodeDTO;
import com.xxh.cloud.frontend.common.modules.his.model.HisDeptListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisDoctorListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisPatientListModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisPromotionCodeModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisSchemeUrlModel;
import com.xxh.cloud.frontend.common.modules.his.model.HisWxTokenModel;
import com.xxh.cloud.frontend.common.modules.his.model.PatBindModel;
import com.xxh.cloud.frontend.common.modules.modules.Result;
import com.xxh.cloud.frontend.common.modules.util.IpWhite;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/api/his")
@Api(tags="调用His互联网医院第三方客户服务接口")
public class HisApiController {

    @Autowired
    private HisWebConfig config;
    @Autowired
    private IpWhite ipWhite;

    /**
     * 暂时使用海慈提供的accessToken
     */
    @GetMapping("/getAccessToken")
    @ApiOperation("获取微信accessToken")
    public Result<HisWxTokenModel> getAccessToken(@RequestParam("type") String type) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        HisWxTokenModel resp = HisWebApiHelper.getAccessToken(config, type);
        
        return new Result<HisWxTokenModel>().ok(resp);
    }

    @GetMapping("/getPatientByUnionId")
    @ApiOperation("获取就诊人信息")
    public Result<PatBindModel> getPatientByUnionId(@RequestParam("unionid") String unionid) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        PatBindModel resp = HisWebApiHelper.getPatientByUnionId(config, unionid);
        
        return new Result<PatBindModel>().ok(resp);
    }

    @PostMapping("/getPatientByThirdId")
    @ApiOperation("获取就诊人信息")
    public Result<PatBindModel> getPatientByThirdId(@RequestBody HisPatientDTO params) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        PatBindModel resp = HisWebApiHelper.getPatientByThirdId(config, params);
        
        return new Result<PatBindModel>().ok(resp);
    }

    @PostMapping("/getPatientByTimestamp")
    @ApiOperation("批量获取就诊人信息")
    public Result<HisPatientListModel> getPatientByTimestamp(@RequestBody HisPatientDTO params) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        HisPatientListModel resp = HisWebApiHelper.getPatientByTimestamp(config, params);
        
        return new Result<HisPatientListModel>().ok(resp);
    }

    @GetMapping("/getDeptsInfo")
    @ApiOperation("获取科室信息")
    public Result<HisDeptListModel> getDeptsInfo() {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        HisDeptListModel resp = HisWebApiHelper.getDeptsInfo(config);
        
        return new Result<HisDeptListModel>().ok(resp);
    }

    @GetMapping("/getDoctorsInfo")
    @ApiOperation("获取医生信息")
    public Result<HisDoctorListModel> getDoctorsInfo(@RequestParam(value = "showModel", required = false) String showModel) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        HisDoctorListModel resp = HisWebApiHelper.getDoctorsInfo(config, showModel);
        
        return new Result<HisDoctorListModel>().ok(resp);
    }

    @PostMapping("/getWxMiniSchemeUrl")
    @ApiOperation("获取schemeurl")
    public Result<HisSchemeUrlModel> getWxMiniSchemeUrl(@RequestBody HisGenerateSchemeDTO queryParam) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        HisSchemeUrlModel resp = HisWebApiHelper.getWxMiniSchemeUrl(config, queryParam);
        
        return new Result<HisSchemeUrlModel>().ok(resp);
    }

    @PostMapping("/getAndSavePromotionCodeUrl")
    @ApiOperation("获取并保存推广码")
    public Result<HisPromotionCodeModel> getAndSavePromotionCodeUrl(@RequestBody HisPromotionCodeDTO queryParam) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        // 获取推广码
        HisPromotionCodeModel resp = HisWebApiHelper.getPromotionCodeUrl(config, queryParam);

        return new Result<HisPromotionCodeModel>().ok(resp);
    }

}
