package com.xxh.cloud.frontend.custuser.web.controller;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.config.WxApiConfig;
import com.company.cloud.wx.sdk.work.inner.WxWorkInnerApi;
import com.company.cloud.wx.sdk.work.inner.model.Code2TicketModel;
import com.company.cloud.wx.sdk.work.inner.model.Code2TicketResp;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendResp;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendTextCardModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendTextCardModel.TextCard;
import com.company.cloud.wx.sdk.work.intra.WxWorkCommonApi;
import com.company.cloud.wx.sdk.work.model.common.AccessTokenModel;
import com.company.cloud.wx.sdk.work.model.common.AccessTokenResp;
import com.xxh.cloud.frontend.common.modules.exception.BusinessException;
import com.xxh.cloud.frontend.common.modules.modules.Result;
import com.xxh.cloud.frontend.common.modules.util.IpWhite;
import com.xxh.cloud.frontend.common.modules.weixin.dto.SendWxWorkMsgDTO;

import cn.hutool.core.util.StrUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;

@Log4j2
@RestController
@RequestMapping("/sys/healthy/wechat/third/work")
@Api(tags = "企业微信相关")
public class WechatWorkController {

    @Autowired
    private IpWhite ipWhite;

    @PostMapping("/getAccessToken")
    @ApiOperation(value = "企业微信-获取AccessToken", response = Result.class)
    public Result<AccessTokenResp> getWorkAccessToken(@RequestBody WxApiConfig config) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        // 获取accessToken
        AccessTokenModel accessTokenModel = new AccessTokenModel();
        accessTokenModel.setCorpid(config.getAppid());
        accessTokenModel.setCorpsecret(config.getSecret());
        AccessTokenResp accessTokenResp = WxWorkCommonApi.accessToken(accessTokenModel);
        if (accessTokenResp.getErrcode() != 0 || StrUtil.isBlank(accessTokenResp.getAccess_token())) {
            throw new BusinessException("获取token失败");
        }

        return new Result<AccessTokenResp>().ok(accessTokenResp);
    }

    // 在xx-user中：/app/sys/userlogin/oauth2
    // @GetMapping("/empower")
    // @ApiOperation(value = "企业微信授权接口", response = String.class)
    // public void workEmpower(HttpServletResponse response) {
    //     log.info("/sys/healthy/wechat/msg/third/work/empower >>>>>>");
    //     try {
    //         Authorize2CodeModel authorize2CodeModel = new Authorize2CodeModel();
    //         authorize2CodeModel.setAppId(corpid);
    //         authorize2CodeModel.setRedirectUri(redirectUri);
    //         authorize2CodeModel.setResponseType("code");
    //         authorize2CodeModel.setScope(scope);
    //         authorize2CodeModel.setState(state);
    //         authorize2CodeModel.setAgentId(agentid);
    //         response.sendRedirect(WxWorkInnerApi.authorize2Code(authorize2CodeModel));
    //     } catch (IOException e) {
    //         // TODO Auto-generated catch block
    //         e.printStackTrace();
    //     }
    // }

    @PostMapping("/getUserInfo")
    @ApiOperation(value = "企业微信-获取用户身份", response = Result.class)
    public Result<Code2TicketResp> getWorkUserInfo(@RequestBody Code2TicketModel params) {
        // ip白名单限制
        ipWhite.validatorIpWhite();
        
        return new Result<Code2TicketResp>().ok(WxWorkInnerApi.getUserInfo(params));
    }

    @PostMapping("/sendAgentMsg")
    @ApiOperation(value = "企业微信-发送应用消息", response = Result.class)
    public Result<MessageSendResp> sendAgentMsg(@RequestBody SendWxWorkMsgDTO params) {
        // ip白名单限制
        ipWhite.validatorIpWhite();

        MessageSendResp resp = null;
        if ("textcard".equals(params.getMsgtype())) {
            resp = this.sendTextCardMsg(params);
        }

        return new Result<MessageSendResp>().ok(resp);
    }

    // 文本卡片消息
    private MessageSendResp sendTextCardMsg(SendWxWorkMsgDTO params) {
        
        MessageSendTextCardModel model = new MessageSendTextCardModel();
        model.setAccess_token(params.getAccessToken());
        model.setAgentid(params.getAgentid());
        model.setTouser(params.getOpenid());
        model.setMsgtype("textcard");

        Map<String, String> paramMap = params.getData();
        TextCard textCard = new TextCard();
        textCard.setTitle(paramMap.get("title"));
        textCard.setDescription(paramMap.get("description"));
        textCard.setUrl(paramMap.get("url"));
        textCard.setBtntxt(paramMap.get("btntxt"));
        model.setTextcard(textCard);

        // 发送
        log.info("wechat work request send textcard message >>> : {}", JSONObject.toJSONString(model));
        MessageSendResp resp = WxWorkInnerApi.messageSendTextcard(model);
        log.info("wechat work response send textcard message <<< : {}", JSONObject.toJSONString(resp));
        
        return resp;
    }

}
