package com.xxh.cloud.frontend.mq.service.impl;

import cn.hutool.json.JSONUtil;
import com.xxh.cloud.frontend.mq.model.ActiveMqTypeEnum;
import com.xxh.cloud.frontend.mq.model.MqMessageModel;
import com.xxh.cloud.frontend.mq.model.MqSendDelayModel;
import com.xxh.cloud.frontend.mq.model.MqSendModel;
import com.xxh.cloud.frontend.mq.service.ActiveMqService;
import lombok.extern.slf4j.Slf4j;
import org.apache.activemq.ScheduledMessage;
import org.apache.activemq.command.ActiveMQQueue;
import org.apache.activemq.command.ActiveMQTopic;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jms.core.JmsMessagingTemplate;
import org.springframework.jms.core.JmsTemplate;
import org.springframework.stereotype.Service;

import javax.jms.Destination;
import javax.jms.Queue;
import javax.jms.TextMessage;
import javax.jms.Topic;

@Slf4j
@Service
public class ActiveMqServiceImpl implements ActiveMqService {

    @Autowired
    private JmsMessagingTemplate jmsMessagingTemplate;

    @Override
    public void send(MqSendModel model) {
        if (ActiveMqTypeEnum.QUEUE.getCode().equals(model.getSendModel())) {
            Queue queue = new ActiveMQQueue(model.getTarget());
            sendMessage(queue, model.getContent());
        } else if (ActiveMqTypeEnum.TOPIC.getCode().equals(model.getSendModel())) {
            Topic topic = new ActiveMQTopic(model.getTarget());
            sendMessage(topic, model.getContent());
        } else {
            log.error("MQ队列类型错误");
        }
    }

    @Override
    public void delay(MqSendDelayModel model) {
        if (ActiveMqTypeEnum.QUEUE.getCode().equals(model.getSendModel())) {
            Queue queue = new ActiveMQQueue(model.getTarget());
            sendMessageDelay(queue, model.getContent(), model.getDelay());
        } else if (ActiveMqTypeEnum.TOPIC.getCode().equals(model.getSendModel())) {
            Topic topic = new ActiveMQTopic(model.getTarget());
            sendMessageDelay(topic, model.getContent(), model.getDelay());
        } else {
            log.error("MQ队列类型错误");
        }
    }

    @Override
    public void send(String sendModel, String target, String tag, Object content) {
        MqMessageModel mqMessageModel = new MqMessageModel(tag, JSONUtil.toJsonStr(content));
        MqSendModel mqSendModel = new MqSendModel(sendModel, target, mqMessageModel);
        this.send(mqSendModel);
    }

    @Override
    public void delay(String sendModel, String target, String tag, Object content, Integer delay) {

        MqMessageModel mqMessageModel = new MqMessageModel(tag, JSONUtil.toJsonStr(content));
        MqSendDelayModel mqSendDelayModel = new MqSendDelayModel(sendModel, target, mqMessageModel , delay);
        this.delay(mqSendDelayModel);
    }

    // 发送消息，destination是发送到的队列，message是待发送的消息
    private void sendMessage(Destination destination, String content){
        jmsMessagingTemplate.convertAndSend(destination, content);
    }

    // 发送延迟消息，destination是发送到的队列，message是待发送的消息
    private void sendMessageDelay(Destination destination, String content, Integer delay){
        JmsTemplate jmsTemplate = jmsMessagingTemplate.getJmsTemplate();
        assert jmsTemplate != null;
        jmsTemplate.send(destination, session -> {
            TextMessage message = session.createTextMessage(content);
            message.setLongProperty(ScheduledMessage.AMQ_SCHEDULED_DELAY, delay * 1000);
            return message;
        });
    }
}
